/* 
 * Stardust :-) 
 * A Free Space Flight Simulator for a Free Universe!
 * Copyright (C) 2003 MiKael NAVARRO
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <stdlib.h>

#include <assert.h>

#include "sdlib.h"

#include "engine.h"

/*
 * Constructor.
 */
Engine *engine_new(void) {
  /* Allocation de la structure */
  Engine *engine = (Engine *)malloc(sizeof(Engine));
  if(!engine) {
    sd_error("Can't allocate memory (Engine)!");
  }

  /* Engine status */
  engine->atest   = 0;
  engine->verbose = 0;

  engine->session = SESSION_NONE;

  /* Initialize  windows properties */
  /*engine->screen = NULL;*/
  engine->flags = 0;
  engine->width  = 0;
  engine->height = 0;
  engine->bpp    = 0;

  /* Initialize camera */
  engine->fovy  = 0.0;
  engine->aspect = 0.0;
  engine->near = 0.0;
  engine->far  = 0.0;

  /* Frame rate */
  engine->fps = 0;
  engine->frame_rate = 0; 
  engine->ticks        = 0;
  engine->elapsed_time = 0;

  /* Initialize mission */
  memset(engine->mission_file, '\0', FILENAME_LGTH);
  engine->mission = mission_new();

  /* Initialize world */
  engine->scene = scene_new();

  /* Initialize hud */
  memset(engine->txf_file, '\0', FILENAME_LGTH);
  engine->hud = hud_new();

  return engine;
}

/*
 * Destructor.
 */
int engine_destroy(Engine *engine) {
  /* Assertion */
  assert(engine);
  assert(engine->mission);
  assert(engine->scene);
  assert(engine->hud);

  /* Free memory */
  mission_destroy(engine->mission);
  scene_destroy(engine->scene);
  hud_destroy(engine->hud);
  free(engine);

  return 0;
}

