/* 
 * Stardust :-) 
 * A Free Space Flight Simulator for a Free Universe!
 * Copyright (C) 2003 MiKael NAVARRO
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*
 * Definition of the Engine struct.,
 * and public interface.
 */

#ifndef _ENGINE_H
#define _ENGINE_H

#include <SDL.h>

#include "sdlib.h"

#include "mission.h"
#include "scene.h"
#include "hud.h"

/* Session type */
#define SESSION_NONE   0
#define SESSION_LOCAL  1
#define SESSION_CLIENT 2
#define SESSION_SERVER 4

/*
 * The engine.
 */
typedef struct _Engine {
  /* Variables controlling different rendering mode */
  short atest;   /* atest mode */
  short verbose; /* disp infos */

  short session; /* session type */

  /* Display/window properties */
  /*SDL_surface *screen;*/ /* SDL screen */
  Uint32 flags; /* SDL flags */
  int width;  /* window width */
  int height; /* window height */
  int bpp;    /* bits per pixel */

  /* Context(camera) properties */
  float fovy;
  float aspect;
  float near;
  float far;

  Uint32 fps; /* FPS requested */
  Uint32 frame_rate; /* FPS */
  Uint32 ticks;
  Uint32 elapsed_time;

  char mission_file[FILENAME_LGTH]; /* mission.xml */

  char txf_file[FILENAME_LGTH]; /* font.txf */

  /* Mission */
  Mission *mission;

  /* Space world */
  Scene *scene;

  /* HUD, linked to player ship */
  Hud *hud;

} Engine;

/*
 * Constructor.
 */
Engine *engine_new(void);

/*
 * Destructor.
 */
int engine_destroy(Engine *engine);

/*
 * Access.
 */
#define engine_atest(engine) ((engine)->atest)
#define engine_verbose(engine) ((engine)->verbose)
#define engine_session(engine) ((engine)->session)

#define engine_path(engine) ((engine)->path)

#define engine_scene(engine) ((engine)->scene)
#define engine_mission(engine) ((engine)->mission)
#define engine_hud(engine) ((engine)->hud)

/*
 * Init engine.
 */
int engine_init(Engine *engine, int argc, char **argv);

/*
 * Initialise graphics.
 */
int engine_init_graphics(Engine *engine);

/*
 * Init engine subsections.
 */
int engine_load(Engine *engine);

/*
 * Engine, Game Loop.
 */
int engine_gameloop(Engine *engine);

/*
 * Player commands.
 */
int engine_init_cmds(Engine *engine);
int engine_get_cmds(Engine *engine);

/*
 * Query AIs.
 */
int engine_query_ai(Engine *engine);

/*
 * Update.
 */
int engine_update(Engine *engine);

/*
 * Draw scene.
 */
int engine_draw(Engine *engine);


#endif /* _ENGINE_H */
