/* 
 * Stardust :-) 
 * A Free Space Flight Simulator for a Free Universe!
 * Copyright (C) 2003 MiKael NAVARRO
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <stdlib.h>

#include <assert.h>

#include <SDL.h>

#include <GL/gl.h>

#include "engine.h"

/*
 * Engine, Game Loop.
 */
int engine_gameloop(Engine *engine) {
  short done = 0;

  /* Assertion */
  assert(engine);

  /* Initialize timer */
  engine->ticks = SDL_GetTicks();

  /* Init player commands */
  engine_init_cmds(engine);

  printline("\nGame loop ...\n");
  while(!done) { /* game loop */
    /* Get elapsed time */
    engine->elapsed_time = SDL_GetTicks() - engine->ticks;
    engine->frame_rate = 1000.0f / (float)(engine->elapsed_time);
    /* Re-init timer */
    engine->ticks = SDL_GetTicks();
  
    /* Get player commands */
    done = engine_get_cmds(engine);
  
    /* Move all others ships */
    engine_query_ai(engine);

    /* Update */
    engine_update(engine); /*, engine->elapsed_time);*/

    /* Draw scene */
    engine_draw(engine);

    /* Synchronize fps */
    if(engine->fps) { /* for tests only */
      while((1000.0f/(SDL_GetTicks()-engine->ticks)) > engine->fps) { 
	/* synchronize @ 50 fps ? */ 
      }
    }

    SDL_GL_SwapBuffers(); /* swap SDL/OpenGL buffer */

  } /* end game loop */
  printline("End.\n");

  return 0;
}

