/* 
 * Stardust :-) 
 * A Free Space Flight Simulator for a Free Universe!
 * Copyright (C) 2003 MiKael NAVARRO
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*
 * Definition of the Font struct.,
 * and public interface.
 */

#ifndef _FONT_H
#define _FONT_H

#include <SDL.h>

#include <GL/gl.h>

#include "texfont.h"

/*
 * The font.
 */
typedef struct _Font {
  short exist; /* tex font already created ? */
  TexFont *txf; /* tex font */

  /* Properties of tex font */
  int width;
  int ascent;
  int descent;

  float height; /* size of glyphs on screen */
} Font;

/*
 * Constructor.
 */
Font *font_new(void);

/*
 * Destructor.
 */
int font_destroy(Font *font);

/*
 * Access.
 */
#define font_exist(font) ((font)->exist)

#define font_width(font) ((font)->width)
#define font_ascent(font) ((font)->ascent)
#define font_descent(font) ((font)->descent)

#define font_height(font) ((font)->height)

/*
 * Initialize a font (raster/tex font).
 * If (txf_file!=NULL) try to load a tex font;
 * Else use a default raster font.
 */
int font_init(Font *font, const char *txf_file);

/* 
 * Display text with raster/tex font at position (x,y,z).
 * Parameter size, only usefull with tex font (default 10).
 */
int font_draw(Font *font, const char *str, int size, float x, float y, float z);
#define font_display_text font_draw


#endif /* _FONT_H */
