/* 
 * Stardust :-) 
 * A Free Space Flight Simulator for a Free Universe!
 * Copyright (C) 2003 MiKael NAVARRO
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*
 * Definition of the Hud struct.,
 * and public interface.
 */

#ifndef _HUD_H
#define _HUD_H

#include <SDL.h>

#include <GL/gl.h>

#include "font.h"
#include "spaceship.h"

/*
 * The head-up display.
 */
typedef struct _Hud {
  /* Hud size */
  float width;
  float height;
  float dz;
  float unit; /* unit length */
  float ratio; /* width/height */

  /* Usefull size */
  float w2; /* width/2 */
  float w3; /* width/3 */
  float w4; /* width/4 */
  float w5; /* width/5 */
  float w8; /* width/8 */
  float w10; /* width/10 */
  float w20; /* width/20 */
  float w30; /* width/30 */
  float w40; /* width/40 */
  float w80; /* width/80 */

  float h2; /* height/2 */
  float h5; /* height/5 */

  /* Font */
  Font *font;

  /* Test? */
  short intest;

} Hud;

/*
 * Constructor.
 */
Hud *hud_new(void);

/*
 * Destructor.
 */
int hud_destroy(Hud *hud);

/*
 * Init hud (width, height, pos, font).
 */
int hud_init(Hud *hud, float w, float h, float z, const char *txf_file, const short atest);

/*
 * Draw hud (linked to player ship).
 */
int hud_draw(Hud *hud, SpaceShip *player_ship, const float frame_rate);

/* Following functions are called by hud_draw */
int hud_draw_screen(Hud *hud, SpaceShip *player_ship);
int hud_draw_speed(Hud *hud, SpaceShip *player_ship);
int hud_draw_flying_mode(Hud *hud, SpaceShip *player_ship);
int hud_draw_warnings(Hud *hud, SpaceShip *player_ship);

int hud_draw_message(Hud *hud, SpaceShip *player_ship, const float frame_rate);

int hud_draw_orbe(Hud *hud, SpaceShip *player_ship);

int hud_draw_tri(Hud *hud, SpaceShip *player_ship);
int hud_draw_resources(Hud *hud, SpaceShip *player_ship);
int hud_draw_damages(Hud *hud, SpaceShip *player_ship);

int hud_draw_vessel(Hud *hud, SpaceShip *player_ship);

int hud_draw_camera(Hud *hud, SpaceShip *player_ship);
int hud_draw_contact(Hud *hud, SpaceShip *player_ship);
int hud_draw_contacts(Hud *hud, SpaceShip *player_ship);
int hud_draw_target(Hud *hud, SpaceShip *player_ship);

/* Specific display (NAV/ARM/NRJ/CMD) */
int hud_draw_nav(Hud *hud, SpaceShip *player_ship);
int hud_draw_arm(Hud *hud, SpaceShip *player_ship);
int hud_draw_nrj(Hud *hud, SpaceShip *player_ship);
int hud_draw_cmd(Hud *hud, SpaceShip *player_ship);


#endif /* _HUD_H */
