/* 
 * Stardust :-) 
 * A Free Space Flight Simulator for a Free Universe!
 * Copyright (C) 2004 MiKael NAVARRO
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <stdlib.h>

#include <assert.h>

#include "hud.h"

/*
 * Draw gun sights.
 */
static int hud_draw_gun_sights(Hud *hud) {
  float x, y, z, o, d;

  /* Assertion */
  assert(hud);

  /* Center */
  x = 0.0;
  y = 0.0;
  z = -hud->dz - 0.1;
  /* Size */
  o = hud->w80;
  d = 2.0 * o;

  /* Draw gun sights */
  glColor4f(1.0, 0.0, 0.0, 0.8);
  glBegin(GL_POINTS);
  glVertex3f(0.0, 0.0, z);
  glEnd();
  glBegin(GL_LINES);
  glVertex3f(x-d, y+o, z);
  glVertex3f(x-o, y+o, z);
  glVertex3f(x-o, y+o, z);
  glVertex3f(x-o, y+d, z);
  glVertex3f(x+d, y+o, z);
  glVertex3f(x+o, y+o, z);
  glVertex3f(x+o, y+o, z);
  glVertex3f(x+o, y+d, z);
  glVertex3f(x-d, y-o, z);
  glVertex3f(x-o, y-o, z);
  glVertex3f(x-o, y-o, z);
  glVertex3f(x-o, y-d, z);
  glVertex3f(x+d, y-o, z);
  glVertex3f(x+o, y-o, z);
  glVertex3f(x+o, y-o, z);
  glVertex3f(x+o, y-d, z);
  glEnd();

  return 0;
}

/*
 * Display fire mode (edge middle-up).
 */
static int hud_draw_fire_mode(Hud *hud, SpaceShip *player_ship) {
  float x, y, z, d;

  /* Assertion */
  assert(hud);
  assert(hud->font);
  assert(player_ship);

  /* Edge middle-up */
  x = 0.0;
  y = hud->h2 - hud->unit;
  z = -hud->dz - 0.1;
  /* Size */
  d = 2.0*hud->unit;

  /* Display flying_mode */
  glColor4f(1.0, 1.0, 0.0, 0.8);
  font_draw(hud->font, "L C", 8, x+d, y-2.0*d, z);

  return 0;
}

/*
 * Draw torpedos.
 */
int hud_draw_torpedos(Hud *hud, SpaceShip *player_ship) {
  /* Assertion */
  assert(hud);
  assert(player_ship);

  /* TODO */

  return 0;
}

/*
 * Draw ARM controls.
 */
int hud_draw_arm(Hud *hud, SpaceShip *player_ship) {
  /* Assertion */
  assert(hud);
  assert(player_ship);

  /* Draw gun sights */
  hud_draw_gun_sights(hud);

  /* Display fire mode */
  hud_draw_fire_mode(hud, player_ship);

  return 0;
}
