/* 
 * Stardust :-) 
 * A Free Space Flight Simulator for a Free Universe!
 * Copyright (C) 2004 MiKael NAVARRO
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <stdlib.h>

#include <assert.h>

#include "sdlib.h"

#include "hud.h"

/*
 * Draw camera (corner up-right).
 */
int hud_draw_camera(Hud *hud, SpaceShip *player_ship) {
  float x, y, z, w, h;

  /* Assertion */
  assert(hud);
  assert(player_ship);

  /* Corner up-right */
  x = hud->w2 - 2.0*hud->unit; 
  y = hud->h2 - 2.0*hud->unit;
  z = -hud->dz - 0.1;
  /* Size */
  w = hud->w5;
  h = hud->h5;

  /* Draw camera */
  glColor4f(1.0, 0.0, 0.0, 0.8);
  glBegin(GL_LINE_LOOP);
  glVertex3f(x-w, y, z);
  glVertex3f(x, y, z);
  glVertex3f(x, y-h, z);
  glVertex3f(x-w, y-h, z);
  glEnd();
  
  return 0;
}

/*
 * Display contact infos (edge middle-bottom).
 */
static int hud_draw_contact_infos(Hud *hud, SpaceShip *player_ship) {
  float x, y, z, w, d;

  /* Assertion */
  assert(hud);
  assert(player_ship);

  /* Edge middle-bottom */
  x = hud->w30;
  y = -hud->h2 + 2.0*hud->unit;
  z = -hud->dz - 0.1;
  /* Size */
  w = hud->width * (3.0 / 20.0);
  d = hud->w40;

  /* Draw contact infos */
  glBegin(GL_LINE_LOOP);
  glVertex3f(x, y, z);
  glVertex3f(x+w, y, z);
  glVertex3f(x+w, y+w-d, z);
  glVertex3f(x+w-d, y+w, z);
  glVertex3f(x, y+w, z);
  glEnd();

  return 0;
}

/*
 * Display contacts list (edge middle-bottom).
 */
int hud_draw_contacts(Hud *hud, SpaceShip *player_ship) {
  float x, y, z, w, h, d;

  /* Assertion */
  assert(hud);
  assert(player_ship);

  /* Edge middle-bottom */
  x = hud->w30 - hud->unit/2.0;
  y = -hud->h2 + 2.0*hud->unit;
  z = -hud->dz - 0.1;
  /* Size */
  w = hud->w5;
  h = hud->w40;
  d = hud->unit / 5.0;

  /* Draw contact */
  switch (model_desc_camp(space_ship_model(player_ship))) {
  case UNK:
    glColor4f(1.0, 1.0, 0.0, 0.8);
    break;
  case NEU:
    glColor4f(0.0, 1.0, 0.0, 0.8);
    break;
  case NVY:
    glColor4f(0.0, 0.0, 1.0, 0.8);
    break;
  case ENY:
    glColor4f(1.0, 0.1, 0.0, 0.8);
    break;
  default:
    sd_warning("Must never happen!");
  }
  glBegin(GL_LINE_LOOP);
  glVertex3f(x, y, z);
  glVertex3f(x-w+d, y, z);
  glVertex3f(x-w, y+d, z);
  glVertex3f(x-w, y+h-d, z);
  glVertex3f(x-w+d, y+h, z);
  glVertex3f(x, y+h, z);
  glEnd();

  /* Display contact infos */
  hud_draw_contact_infos(hud, player_ship);

  glColor4f(1.0, 1.0, 0.0, 0.8); /* TODO: remove */

  /* Draw next contact */
  y += h + hud->unit/2.0;
  glBegin(GL_LINE_LOOP);
  glVertex3f(x, y, z);
  glVertex3f(x-w+d, y, z);
  glVertex3f(x-w, y+d, z);
  glVertex3f(x-w, y+h-d, z);
  glVertex3f(x-w+d, y+h, z);
  glVertex3f(x, y+h, z);
  glEnd();

  /* Draw next contact */
  y += h + hud->unit/2.0;
  glBegin(GL_LINE_LOOP);
  glVertex3f(x, y, z);
  glVertex3f(x-w+d, y, z);
  glVertex3f(x-w, y+d, z);
  glVertex3f(x-w, y+h-d, z);
  glVertex3f(x-w+d, y+h, z);
  glVertex3f(x, y+h, z);
  glEnd();

  /* Draw next contact */
  y += h + hud->unit/2.0;
  glBegin(GL_LINE_LOOP);
  glVertex3f(x, y, z);
  glVertex3f(x-w+d, y, z);
  glVertex3f(x-w, y+d, z);
  glVertex3f(x-w, y+h-d, z);
  glVertex3f(x-w+d, y+h, z);
  glVertex3f(x, y+h, z);
  glEnd();

  /* Draw next contact */
  y += h + hud->unit/2.0;
  glBegin(GL_LINE_LOOP);
  glVertex3f(x, y, z);
  glVertex3f(x-w+d, y, z);
  glVertex3f(x-w, y+d, z);
  glVertex3f(x-w, y+h-d, z);
  glVertex3f(x-w+d, y+h, z);
  glVertex3f(x, y+h, z);
  glEnd();

  return 0;
}

/*
 * Display contact infos.
 */
int hud_draw_contact(Hud *hud, SpaceShip *player_ship) {
  float x, y, z, w, h, d;

  /* Assertion */
  assert(hud);
  assert(player_ship);

  /* Edge middle-bottom */
  x = hud->w30 - hud->unit/2.0;
  y = -hud->h2 + 2.0*hud->unit;
  z = -hud->dz - 0.1;
  /* Size */
  w = hud->w5;
  h = hud->w40;
  d = hud->unit / 5.0;

  /* Draw contact */
  switch (model_desc_camp(space_ship_model(player_ship))) {
  case UNK:
    glColor4f(1.0, 1.0, 0.0, 0.8);
    break;
  case NEU:
    glColor4f(0.0, 1.0, 0.0, 0.8);
    break;
  case NVY:
    glColor4f(0.0, 0.0, 1.0, 0.8);
    break;
  case ENY:
    glColor4f(1.0, 0.1, 0.0, 0.8);
    break;
  default:
    sd_warning("Must never happen!");
  }
  glBegin(GL_LINE_LOOP);
  glVertex3f(x, y, z);
  glVertex3f(x-w+d, y, z);
  glVertex3f(x-w, y+d, z);
  glVertex3f(x-w, y+h-d, z);
  glVertex3f(x-w+d, y+h, z);
  glVertex3f(x, y+h, z);
  glEnd();

  return 0;
}

/*
 * Draw target sights.
 */
int hud_draw_target(Hud *hud, SpaceShip *player_ship) {
  /* Assertion */
  assert(hud);
  assert(player_ship);

  /* Draw target sights */
  /* TODO */

  return 0;
}

