/* 
 * Stardust :-) 
 * A Free Space Flight Simulator for a Free Universe!
 * Copyright (C) 2004 MiKael NAVARRO
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <stdlib.h>

#include <assert.h>

#include <GL/glu.h>

#include "hud.h"

#include "mat.h"

/*
 * Draw sights (center).
 */
static int hud_draw_sights(Hud *hud) {
  float x, y, z, o, d;

  /* Assertion */
  assert(hud);

  /* Center */
  x = 0.0;
  y = 0.0;
  z = -hud->dz - 0.1;
  /* Size */
  o = hud->w80;
  d = hud->w20;

  /* Draw sights */
  glColor4f(1.0, 0.0, 0.0, 0.8);
  glBegin(GL_POINTS);
  glVertex3f(0.0, 0.0, z);
  glEnd();
  glBegin(GL_LINES);
  glVertex3f(o, 0.0, z);
  glVertex3f(d, 0.0, z);
  glVertex3f(-o, 0.0, z);
  glVertex3f(-d, 0.0, z);
  glVertex3f(0.0, o, z);
  glVertex3f(0.0, d, z);
  glVertex3f(0.0, -o, z);
  glVertex3f(0.0, -d, z);
  glEnd();

  return 0;
}

/*
 * Draw nav controls (center).
 */
static int hud_draw_nav_ctrls(Hud *hud, SpaceShip *player_ship) {
  float x, y, z, o, d;
  GLfloat m[16];

  /* Assertion */
  assert(hud);
  assert(player_ship);

  /* Center */
  x = 0.0;
  y = 0.0;
  z = -hud->dz - 0.1;
  /* Size */
  d = hud->w10;
  o = hud->w40;

  /* Draw nav controls */
  glPushMatrix();
#if 1
  invert_mat4(m, space_ship_mat(player_ship));
  m[12] = m[13] = m[14] = 0; /* reset trans */
  glMultMatrixf(m);
#else
 {
   GLfloat mat[16];
   glGetFloatv(GL_MODELVIEW_MATRIX, mat);
   invert_mat4(m, mat);
  m[12] = m[13] = m[14] = 0; /* reset trans */
  glLoadMatrixf(m);
 }
#endif

  glColor4f(1.0, 1.0, 0.0, 0.8);

  glBegin(GL_LINES);
  glVertex3f(x-o, y, z);
  glVertex3f(x-d, y, z);
  glVertex3f(x+d, y, z);
  glVertex3f(x+o, y, z);
  glEnd();

  glPushMatrix();
  glRotatef(1.0, 0.0, 0.0, 10.0);
  glBegin(GL_LINES);
  glVertex3f(x-o, y, -z);
  glVertex3f(x-d, y, -z);
  glVertex3f(x+d, y, -z);
  glVertex3f(x+o, y, -z);
  glEnd();
  glPopMatrix();
  
  glPopMatrix();

  return 0;
}

/*
 * Draw nav cap (edge middle-up).
 */
static int hud_draw_cap(Hud *hud, SpaceShip *player_ship) {
  /* Assertion */
  assert(hud);
  assert(player_ship);

  /* TODO */

  return 0;
}

/*
 * Display autopilot mode (edge middle-up).
 */
static int hud_draw_autopilot_mode(Hud *hud, SpaceShip *player_ship) {
  float x, y, z, d;

  /* Assertion */
  assert(hud);
  assert(hud->font);
  assert(player_ship);

  /* Edge middle-up */
  x = 0.0;
  y = hud->h2 - hud->unit;
  z = -hud->dz - 0.1;
  /* Size */
  d = 2.0*hud->unit;

  /* Display flying_mode */
  glColor4f(1.0, 1.0, 0.0, 0.8);
  font_draw(hud->font, "S A F M", 8, x+d, y-2.0*d, z);

  return 0;
}

/*
 * Draw NAV controls.
 */
int hud_draw_nav(Hud *hud, SpaceShip *player_ship) {
  /* Assertion */
  assert(hud);
  assert(player_ship);

  /* Draw sights */
  hud_draw_sights(hud);

  if(space_ship_hud_detail(player_ship) >= HUD_HIGH_DETAIL) {
    /* Draw nav controls */
    hud_draw_nav_ctrls(hud, player_ship);
    /* Draw nav cap */
    hud_draw_cap(hud, player_ship);
  }

  /* Display autopilot mode */
  hud_draw_autopilot_mode(hud, player_ship);

  return 0;
}
