/* 
 * Stardust :-) 
 * A Free Space Flight Simulator for a Free Universe!
 * Copyright (C) 2004 MiKael NAVARRO
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <stdlib.h>

#include <assert.h>

#include "hud.h"

/*
 * Draw tactical resources interface (corner bottom-right).
 */
int hud_draw_tri(Hud *hud, SpaceShip *player_ship) {
  float x, y, z, w, h, d, e;

  /* Assertion */
  assert(hud);
  assert(player_ship);

  /* Corner bottom-right */
  x = hud->w3 - 2.0*hud->unit; 
  y = -hud->h2 + 2.0*hud->unit;
  z = -hud->dz - 0.1;
  /* Size */
  w = hud->w8;
  h = w * sqrt(3.0/4.0);
  d = w / 6.0;
  e = d * sqrt(3.0/4.0);

  /* Draw tactical resources diagram */
  glColor4f(1.0, 1.0, 1.0, 0.8);
  glBegin(GL_LINE_LOOP);
  glVertex3f(x-w+d, y, z);
  glVertex3f(x-w+d/2.0, y+e, z);
  glVertex3f(x-w/2.0-d/2.0, y+h-e, z);
  glVertex3f(x-w/2.0+d/2.0, y+h-e, z);
  glVertex3f(x-d/2.0, y+e, z);
  glVertex3f(x-d, y, z);
  glEnd();
  glBegin(GL_LINE_LOOP);
  glVertex3f(x-w/2.0-d/2.0, y+h/3.0+e/3.0, z);
  glVertex3f(x-w/2.0+d/2.0, y+h/3.0+e/3.0, z);
  glVertex3f(x-w/2.0, y+h/3.0-e*2.0/3.0, z);
  glEnd();

  return 0;
}

/*
 * Display resources (corner bottom-left).
 */
int hud_draw_resources(Hud *hud, SpaceShip *player_ship) {
  char str[64];
  float x, y, z, w, h, a, b;

  /* Assertion */
  assert(hud);
  assert(hud->font);
  assert(player_ship);

  /* Corner bottom-left */
  x = -hud->w2 + hud->w5 + 2.5*hud->unit; 
  y = -hud->h2 + 2.0*hud->unit;
  z = -hud->dz - 0.1;
  /* Size */
  h = hud->w10;
  w = h / 3.0;
  /* Text */
  a = x + hud->unit/2.0;
  b = y; /* line offset */

  /* Draw resources infos */
  glColor4f(1.0, 1.0, 1.0, 0.8);
#if 0
  glBegin(GL_LINE_LOOP);
  glVertex3f(x, y, z);
  glVertex3f(x, y+h, z);
  glVertex3f(x+w, y+h, z);
  glVertex3f(x+w, y, z);
  glEnd();
  glBegin(GL_LINE_LOOP);
  glVertex3f(x+w, y, z);
  glVertex3f(x+w, y+h, z);
  glVertex3f(x+2.0*w, y+h, z);
  glVertex3f(x+2.0*w, y, z);
  glEnd();
  glBegin(GL_LINE_LOOP);
  glVertex3f(x+2.0*w, y, z);
  glVertex3f(x+2.0*w, y+h, z);
  glVertex3f(x+3.0*w, y+h, z);
  glVertex3f(x+3.0*w, y, z);
  glEnd();
#else
  glBegin(GL_LINE_LOOP);
  glVertex3f(x, y, z);
  glVertex3f(x, y+h/1.5, z);
  glVertex3f(x+h, y+h/1.5, z);
  glVertex3f(x+h, y, z);
  glEnd();
#endif

  /* Display resources infos */
  glColor4f(1.0, 1.0, 0.0, 0.8);
  b += 1.0*hud->unit;
  sprintf(str, "F: %s", 
	  model_desc_autonomy(space_ship_model(player_ship)));
  font_draw(hud->font, str, 8, a, b, z);
  b += 1.5*hud->unit;
  sprintf(str, "R: %s", 
	  model_desc_power(space_ship_model(player_ship)));
  font_draw(hud->font, str, 8, a, b, z);
  b += 1.5*hud->unit;
  sprintf(str, "T: 12000000K"); /* TODO: update */
  font_draw(hud->font, str, 8, a, b, z);

  return 0;
}

/*
 * Display damages.
 */
int hud_draw_damages(Hud *hud, SpaceShip *player_ship) {
  char str[64];
  float x, y, z, a, b;

  /* Assertion */
  assert(hud);
  assert(hud->font);
  assert(player_ship);

  /* Corner bottom-left */
  x = -hud->w2 + 2.0*hud->unit; 
  y = -hud->h2 + 2.0*hud->unit;
  z = -hud->dz - 0.1;
  /* Text */
  a = x + hud->unit;
  b = y; /* line offset */

  /* Display damages */
  glColor4f(1.0, 1.0, 0.0, 0.8);
  b += hud->unit;
  sprintf(str, "HULL: %.0f", 
	  model_desc_hull(space_ship_model(player_ship)));
  font_draw(hud->font, str, 8, a, b, z);

  return 0;
}

/*
 * Draw NRJ controls.
 */
int hud_draw_nrj(Hud *hud, SpaceShip *player_ship) {
  /* Assertion */
  assert(hud);
  assert(player_ship);

  /* TODO */

  return 0;
}
