/* 
 * Stardust :-) 
 * A Free Space Flight Simulator for a Free Universe!
 * Copyright (C) 2004 MiKael NAVARRO
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <stdlib.h>

#include <assert.h>

#include <GL/glu.h>

#include "hud.h"

#include "mat.h"

/*
 * Draw a circle (x-y plane).
 */
static int draw_circle(float r, int n) {
  unsigned int i;
  float a;

  a = 360.0 / (float)n;

  glBegin(GL_LINE_LOOP);
  for(i=0; i<n; i++) {
    glVertex3f(r * m_cos(i*a), r * m_sin(i*a), 0.0);
  }
  glEnd();
  
  return 0;
}

/* 
 * Draw orbe (corner bottom-right).
 */
int hud_draw_orbe(Hud *hud, SpaceShip *player_ship) {
  float x, y, z, r, n, c;
  GLfloat m[16];

  /* Assertion */
  assert(hud);
  assert(player_ship);

  /* Size*/
  r = hud->w10;
  n = 18;
  c = r/6.0;
  /* Corner bottom-right */
  x = hud->w2 - 2.0*hud->unit - r; 
  y = -hud->h2 + 2.0*hud->unit + r;
  z = -hud->dz - 0.1 - r;

  /* Draw orbe */
  glColor4f(0.0, 1.0, 1.0, 0.8);
  glPushMatrix();

  glTranslatef(x, y, z);
  glRotatef(20.0, 1.0, 1.0, 1.0);

  /* Draw a little triangle */
#if 0
  glBegin(GL_LINE_LOOP);
  glVertex3f(-c*0.86, 0.0, c*0.50);
  glVertex3f(c*0.86, 0.0, c*0.50);
  glVertex3f(0.0, 0.0, -c);
  glEnd();
#endif
  glBegin(GL_LINE_LOOP);
  glVertex3f(0.0, 0.0, 0.0);
  glVertex3f(0.0, c, 0.0);
  glVertex3f(0.0, 0.0, -c);
  glEnd();
  /* Draw a little circle */
  glPushMatrix();
  glRotatef(90.0, 1.0, 0.0, 0.0);
  draw_circle(c, 8);
  glPopMatrix();

  /* Compute matrix */
  invert_mat4(m, space_ship_mat(player_ship));
  m[12] = m[13] = m[14] = 0;
  glMultMatrixf(m);

#if 1
  /* Longitudes */
  draw_circle(r, n);

  glPushMatrix();
  glRotatef(90.0, 0.0, 1.0, 0.0);
  draw_circle(r, n);
  glPopMatrix();

  glPushMatrix(); /* other longitudes */
  glRotatef(45.0, 0.0, 1.0, 0.0);
  draw_circle(r, n);
  glRotatef(90.0, 0.0, 1.0, 0.0);
  draw_circle(r, n);
  glPopMatrix();

  /* Latitudes */
  glPushMatrix();
  glRotatef(-90.0, 1.0, 0.0, 0.0);
  draw_circle(r, n);

  glPushMatrix(); /* latitude north */
  glTranslatef(0.0, 0.0, r*(2.0/3.0));
  draw_circle(r*0.75, n);
  glPopMatrix();

  glPushMatrix(); /* latitude south */
  glTranslatef(0.0, 0.0, -r*(2.0/3.0));
  draw_circle(r*0.75, n);
  glPopMatrix();

  glPopMatrix();
#else
  {
    GLUquadricObj *q = NULL;
    
    q = gluNewQuadric();
    gluQuadricDrawStyle(q, GLU_SILHOUETTE);
    gluQuadricNormals(q, GLU_FLAT);
    gluQuadricTexture(q, GLU_FALSE);
    gluQuadricOrientation(q, GLU_INSIDE);

    glPushMatrix();
    glRotatef(90.0, 1.0, 0.0, 0.0);
    gluSphere(q, r, 8, 4);
    glPopMatrix();

    gluDeleteQuadric(q);
  }
#endif

  glPopMatrix();

  return 0;
}

