/* 
 * Stardust :-) 
 * A Free Space Flight Simulator for a Free Universe!
 * Copyright (C) 2004 MiKael NAVARRO
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <stdlib.h>

#include <assert.h>

#include "hud.h"

/*
 * Display player vessel infos.
 */
static int hud_draw_vessel_infos(Hud *hud, SpaceShip *player_ship) {
  char str[64];
  float x, y, z, h, a, b;

  /* Assertion */
  assert(hud);
  assert(hud->font);
  assert(player_ship);

  /* Corner bottom-left */
  x = -hud->w2 + 2.0*hud->unit; 
  y = -hud->h2 + 2.0*hud->unit;
  z = -hud->dz - 0.1;
  /* Size */
  h = hud->w4;
  /* Text */
  a = x + hud->unit;
  b = y + h; /* line offset */

  /* Display vessel infos */
  glColor4f(1.0, 1.0, 0.0, 0.8);
  b -= 2.0*hud->unit;
  sprintf(str, "Id: %s %s", 
	  model_desc_name(space_ship_model(player_ship)),
	  model_desc_type(space_ship_model(player_ship)));
  font_draw(hud->font, str, 8, a, b, z);
  b -= 2.0*hud->unit;
  sprintf(str, "Class: %s", 
	  model_desc_class(space_ship_model(player_ship)));
  font_draw(hud->font, str, 8, a, b, z);
  b -= 2.0*hud->unit;
  sprintf(str, "Cat: %s", 
	  model_desc_category(space_ship_model(player_ship)));
  font_draw(hud->font, str, 8, a, b, z);

  return 0;
}

/*
 * Draw player vessel (corner bottom-left).
 */
int hud_draw_vessel(Hud *hud, SpaceShip *player_ship) {
  float x, y, z, w, h;

  /* Assertion */
  assert(hud);
  assert(player_ship);

  /* Corner bottom-left */
  x = -hud->w2 + 2.0*hud->unit; 
  y = -hud->h2 + 2.0*hud->unit;
  z = -hud->dz - 0.1;
  /* Size */
  w = hud->w5;
  h = hud->w4;

  /* Draw player vessel */
  glColor4f(1.0, 1.0, 0.0, 0.8);
  glBegin(GL_LINE_LOOP);
  glVertex3f(x+w, y, z);
  glVertex3f(x, y, z);
  glVertex3f(x, y+h, z);
  glVertex3f(x+w, y+h, z);
  glEnd();

  /* Display player vessel infos */
  hud_draw_vessel_infos(hud, player_ship);

  return 0;
}

