/* 
 * Stardust :-) 
 * A Free Space Flight Simulator for a Free Universe!
 * Copyright (C) 2003 MiKael NAVARRO
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <stdlib.h>
#include <string.h>

#include <assert.h>

#include "sdlib.h"

#include "mission.h"

#include "xml.h"

/*
 * Constructor.
 */
Mission *mission_new(void) {
  /* Allocation de la structure */
  Mission *mission = (Mission *)malloc(sizeof(Mission));
  if(!mission) {
    sd_error("Can't allocate memory (Mission)!");
  }

  /* Mission init */
  sprintf(mission->name, "None");

  return mission;
}

/*
 * Destructor.
 */
int mission_destroy(Mission *mission) {
  /* Assertion */
  assert(mission);

  /* Free memory */
  free(mission);

  return 0;
}

/*
 * Init mission from xml file.
 */
int mission_read_xml(Mission *mission, const char *xml_file) {
  Xml *document = NULL;
  char *val = NULL;

  /* Assertion */
  assert(mission);

  /* Init */
  document = xml_new();
  printline("\nParsing mission file: %s\n", xml_file);
  xml_init(document, xml_file);

  /* Parse xml file */
  val = xml_search_path(document, "/Stardust/universe/id/name/text()");
  strcpy(mission->name, val);

  { /* Parse scenes part */
    const char *path_scn = "/Stardust/universe/scenes[@*]/%s/text()";
    char *path;
    unsigned int i;

    path = malloc((strlen(path_scn) + strlen("scn")) * sizeof(char));
    if(!path) {
      sd_error("Not enough memory!");
    }

    /*val = xml_search_path(document, "/Stardust/universe/scenes/@nb");*/

    /* Search scenes */
    sprintf(path, path_scn, "scn");
    i = 0;
    while( (val = xml_search_xpath(document, path, i)) ) {
	i++;
      }

    /* Search connections */
    sprintf(path, path_scn, "cnx");
    i = 0;
    while( (val = xml_search_xpath(document, path, i)) ) {
      i++;
    }

    free(path);
  }

  /* Parse mission (objectives) part */
  val = xml_search_path(document, "/Stardust/mission/brief/text()");

  /* Free memory */
  xml_destroy(document);

  return 0;
}
