/* 
 * Stardust :-) 
 * A Free Space Flight Simulator for a Free Universe!
 * Copyright (C) 2003 MiKael NAVARRO
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*
 * Definition of the ModelDesc struct.,
 * and public interface.
 */

#ifndef _MODELDESC_H
#define _MODELDESC_H

#include "obj.h"

/* Camps */
#define UNK YELLOW
#define NEU GREEN
#define NVY BLUE
#define ENY RED
#define UNKNOWN    UNK
#define NEUTRAL    NEU
#define NAVY       NVY
#define FEDERATION NVY
#define ENNEMY     ENY
#define ALLIANCE   ENY

/*
 * The Model Description.
 */
typedef struct _ModelDesc {
  /* Identification */
  char name[32];
  char class[32];
  char category[32];
  char type[32];
  short camp;

  /* Description */
  char manoeuvrability[32];
  char power[32];
  char range[32];
  char autonomy[32];
  char crew[32];
  char tonnage[32];
  char freight[32];

  Obj *obj; /* object */
  float length;
  float width;
  float height;
  float radius; /* bsphere radius */

  /* Caracteristics */
  float hit_points;
  float hull;
  float armour;

  /* Max linear acceleration (m/s/s) */
  float forward_accel;
  float back_accel;
  float lateral_accel; /* right/left */
  float up_accel;
  float down_accel;
  /* Max linear speed (m/s) */
  float forward_velocity;
  float back_velocity;
  float lateral_velocity; /* right/left */
  float up_velocity;
  float down_velocity;
  
  /* Max angular rotation acceleration (deg/s/s) */
  float yaw_accel; /* or heading */
  float pitch_accel;
  float roll_accel;
  /* Max angular rotation speed (deg/s) */
  float yaw_velocity; /* or heading */
  float pitch_velocity;
  float roll_velocity;

} ModelDesc;

/*
 * Constructor.
 */
ModelDesc *model_desc_new(void);

/*
 * Destructor.
 */
int model_desc_destroy(ModelDesc *model_desc);

/*
 * Access.
 */
#define model_desc_name(model_desc) ((model_desc)->name)
#define model_desc_class(model_desc) ((model_desc)->class)
#define model_desc_category(model_desc) ((model_desc)->category)
#define model_desc_type(model_desc) ((model_desc)->type)
#define model_desc_camp(model_desc) ((model_desc)->camp)

#define model_desc_manoeuvrability(model_desc) ((model_desc)->manoeuvrability)
#define model_desc_power(model_desc) ((model_desc)->power)
#define model_desc_range(model_desc) ((model_desc)->range)
#define model_desc_autonomy(model_desc) ((model_desc)->autonomy)
#define model_desc_crew(model_desc) ((model_desc)->crew)
#define model_desc_tonnage(model_desc) ((model_desc)->tonnage)
#define model_desc_freight(model_desc) ((model_desc)->freight)

#define model_desc_obj(model_desc) ((model_desc)->obj)
#define model_desc_length(model_desc) ((model_desc)->length)
#define model_desc_width(model_desc) ((model_desc)->width)
#define model_desc_height(model_desc) ((model_desc)->height)
#define model_desc_radius(model_desc) ((model_desc)->radius)

#define model_desc_hit_points(model_desc) ((model_desc)->hit_points)
#define model_desc_hull(model_desc) ((model_desc)->hull)
#define model_desc_is_alive model_desc_hull
#define model_desc_armour(model_desc) ((model_desc)->armour)

#define model_desc_forward_accel(model_desc) ((model_desc)->forward_accel)
#define model_desc_back_accel(model_desc) ((model_desc)->back_accel)
#define model_desc_lateral_accel(model_desc) ((model_desc)->lateral_accel)
#define model_desc_up_accel(model_desc) ((model_desc)->up_accel)
#define model_desc_down_accel(model_desc) ((model_desc)->down_accel)

#define model_desc_forward_velocity(model_desc) ((model_desc)->forward_velocity)
#define model_desc_back_velocity(model_desc) ((model_desc)->back_velocity)
#define model_desc_lateral_velocity(model_desc) ((model_desc)->lateral_velocity)
#define model_desc_up_velocity(model_desc) ((model_desc)->up_velocity)
#define model_desc_down_velocity(model_desc) ((model_desc)->down_velocity)

#define model_desc_yaw_accel(model_desc) ((model_desc)->yaw_accel)
#define model_desc_pitch_accel(model_desc) ((model_desc)->pitch_accel)
#define model_desc_roll_accel(model_desc) ((model_desc)->roll_accel)

#define model_desc_yaw_velocity(model_desc) ((model_desc)->yaw_velocity)
#define model_desc_pitch_velocity(model_desc) ((model_desc)->pitch_velocity)
#define model_desc_roll_velocity(model_desc) ((model_desc)->roll_velocity)

/*
 * Initialization.
 */
int model_desc_read_xml(ModelDesc *model_desc, const char *model_file);
#define model_desc_init(model_desc) model_desc_read_xml(model_desc, "data/xml/ships/tug.xml")
#define model_desc_load model_desc_read_xml

/*
 * Draw.
 */
int model_desc_draw(ModelDesc *model_desc);


#endif /* _MODELDESC_H */
