/* 
 * Stardust :-) 
 * A Free Space Flight Simulator for a Free Universe!
 * Copyright (C) 2003 MiKael NAVARRO
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*
 * Definition of the (Alias Wavefront) OBJ struct.,
 * and public interface.
 */

#ifndef _OBJ_H
#define _OBJ_H

#include <stdio.h>

#include <GL/gl.h>

#include "texture.h"

/* Method to render object */
#define DISPLAY_LIST 0
#define VERTEX_ARRAY 1

/* Colors */
#define YELLOW 0
#define GREEN  1
#define BLUE   2
#define RED    3

/*
 * Object structure.
 */
typedef struct _Obj {
  char name[32]; /* object name */
  int nbvertices, nbfaces;
  /* Display List */
  GLuint id;
  /* Texture */
  Texture *texture;
  /* Vertex Arrays */
  GLfloat *inter;
  GLuint *indices;
  /* Object properties */
  float sizemax;
  float centre[3], barycentre[3];
  /* Bounding Box */
  float min[3], max[3];
  /* Bounding Sphere */
  float radius;
} Obj;

/*
 * Constructor.
 */
Obj *obj_new(void);

/*
 * Destructor.
 */
int obj_destroy(Obj *obj);

/*
 * Access.
 */
#define obj_nbvertices(obj) ((obj)->nbvertices)
#define obj_nbfaces(obj) ((obj)->nbfaces)

#define obj_id(obj) ((obj)->id)

#define obj_sizemax(obj) ((obj)->sizemax)
#define obj_centre(obj) ((obj)->centre)
#define obj_barycentre(obj) ((obj)->barycentre)

#define obj_min(obj) ((obj)->min)
#define obj_max(obj) ((obj)->max)

#define obj_radius(obj) ((obj)->radius)

/* 
 * Load a Wavefront OBJ file.
 * Return the display list idx.
 */
GLuint obj_load(Obj *obj, const char *obj_file);
#define obj_init obj_load

/*
 * Draw a Wavefront OBJ.
 * With method= DisplayList | VertexArray.
 */
int obj_draw(Obj *obj, int method);

/*
 * Draw a parallelepiped (center @<0,0,0>).
 * Return the display list idx.
 */
GLuint obj_draw_parallelepiped(float length, float width, float height, 
			       short color);


#endif /* _OBJ_H */
