/*
 * Stardust :-) 
 * A Free Space Flight Simulator for a Free Universe!
 * Copyright (C) 2003 MiKael NAVARRO
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/* 
 * Simple quaternion routines. This file is meant to be included 
 * in a .c file, hence all the routines are defined statically.
 * A good C compiler should be able to automatically inline all
 * these routines. 
 */

#ifndef _QUAT_H
#define _QUAT_H

/*
 * Quaternion.
 */
typedef float quat_t[4];

/*
 * Make identity quaternion.
 */
void ident_quat(float *q);
#define q_zero ident_quat
#define q_ident ident_quat

/*
 * Set quaternion.
 */
void init_quat(float *q, const float x, const float y, const float z, const float w);
#define q_set init_quat

/*
 * Copy src in dst.
 */
void copy_quat(float *dst, const float *src);

/*
 * Invert.
 */
void invert_quat(float *q);
#define q_invert invert_quat

/*
 * Conjugate.
 */
void conjugate_quat(float *q);
#define conj_quat conjugate_quat
#define q_conj conjugate_quat

/*
 * Normalize.
 */
void normalize_quat(float *q);
#define normalise_quat normalize_quat
#define norm_quat normalize_quat
#define magnitude_quat normalize_quat
#define q_norm normalize_quat
#define q_normal q_norm

/*
 * Addition : q = q1 + q2 .
 * Adding quaternions to get a compound rotation is analagous to adding
 * translations to get a compound translation.
 */
void add_quats(float *q, const float *q1, const float *q2);
#define q_add add_quats

/*
 * Multiplication : q = q1 * q2 .
 */
void mult_quats(float *q, const float *q1, const float *q2);
#define q_mult mult_quats

/* 
 * Sphere Linear intERPolation of quaternions.
 */
void slerp_quats(float *res, const float *from, const float *to, const float t);
#define q_slerp slerp_quats

/*
 * Euler angles -> Quat.
 */
void euler_to_quat(float *q, const float yaw, const float pitch, const float roll);
#define q_euler euler_to_quat

/*
 * Make quaternion from axis/amgle (in degrees).
 */
void axis_to_quat(float *q, const float *a, const float phi);
#define q_angle axis_to_quat

/*
 * Compute angle/axis from a quaternion.
 */
void quat_to_axis(float *a, float phi, const float *q);
#define q_axis quat_to_axis

/* 
 * Convertion Mat -> Quat.
 */
void mat_to_quat(float *q, const float *m);

/*
 * Builds a rotation matrix in Matrix based on given quaternion.
 */
void quat_to_mat(float *m, const float *q);

/*
 * A useful function, builds a rotation matrix in Matrix based on
 * given quaternion.
 */
void build_rotmatrix(float *m, const float *q);

/* This size should really be based on the distance from the center 
   of rotation to the point on the object underneath the mouse. 
   That point would then track the mouse as closely as possible. 
   This is a simple example, though, so that is left as an Exercise 
   for the Programmer. */
#define TRACKBALLSIZE (0.8)

/*
 * Pass the x and y coordinates of the last and current positions of
 * the mouse, scaled so they are from (-1.0 ... 1.0).
 * The resulting rotation is returned as a quaternion rotation in the
 * first paramater.
 */
void trackball(float *q, 
               const float p1x, const float p1y, 
	       const float p2x, const float p2y);

/*
 * Test the libruary.
 */
void test_quats(void);
#define q_test test_quats

#endif /* _QUAT_H */
