/* 
 * Stardust :-) 
 * A Free Space Flight Simulator for a Free Universe!
 * Copyright (C) 2003 MiKael NAVARRO
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*
 * Definition of the Scene struct.,
 * and public interface.
 */

#ifndef _SCENE_H
#define _SCENE_H

#include "stars.h"
/*#include "spaceobject.h"*/
#include "spaceship.h"

/* Scene constants */
#define MAX_OBJECTS 100
#define MAX_SHIPS 20

/*
 * The scene.
 */
typedef struct _Scene {
  /* Starsfield / Nebula */
  Stars *stars;

  /* Space Objects (planet, asteroids, ...) */
  /*SpaceObject *space_objects[MAX_OBJECTS];*/

  /* Space Ships */
  SpaceShip *space_ships[MAX_SHIPS]; /* player_ship = space_ships[0] */
  int nb_space_ships;

} Scene;

/*
 * Constructor.
 */
Scene *scene_new(void);

/*
 * Destructor.
 */
int scene_destroy(Scene *scene);

/*
 * Access.
 */
#define scene_starsfield(scene) ((scene)->stars)
#define scene_player_ship(scene) ((scene)->space_ships[0])
#define scene_nb_space_ships(scene) ((scene)->nb_space_ships)
#define scene_space_ship(scene, i) ((scene)->space_ships[i])
/*#define scene_nb_space_objects(scene) (MAX_OBJECTS)
  #define scene_space_object(scene, i) ((scene)->space_objects[i])*/

/*
 * Init world.
 */
int scene_parse_xml(Scene *scene, const char *scn_file);
#define scene_init scene_parse_xml

/*
 * Update world.
 */
int scene_update(Scene *scene, const float dt);

/*
 * Check collisions.
 */
int scene_check_collisions(Scene *scene);

/*
 * Draw world.
 */
int scene_draw(Scene *scene);


#endif /* _SCENE_H */
