/* 
 * Stardust :-) 
 * A Free Space Flight Simulator for a Free Universe!
 * Copyright (C) 2003 MiKael NAVARRO
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "sdlib.h"

/* Max line length for sd_error ans sd_warning. */
#define BUFFER_LGTH (256)

/*
 * Print an error message on stderr and exit.
 */
void sdf_error(char *fmt, ...) {
  int ret = 0;
  char buffer[BUFFER_LGTH];
  va_list args;

  va_start(args, fmt);
  ret = vsprintf(buffer, fmt, args);

  /* Make sure that the output is terminated by a new line */
  if(buffer[strlen(buffer)-1]!='\n') {
    int l = strlen(buffer);
    buffer[l] = '\n';
    buffer[l+1] = '\0';
  }

  fprintf(stderr, buffer);
  va_end(args);

  exit(SD_FAILURE);
}

/*
 * Print a warning message on stderr.
 */
void sdf_warning(char *fmt, ...) {
  int ret = 0;
  char buffer[BUFFER_LGTH];
  va_list args;

  va_start(args, fmt);
  ret = vsprintf(buffer, fmt, args);

  /* Make sure that the output is terminated by a new line */
  if(buffer[strlen(buffer)-1]!='\n') {
    int l = strlen(buffer);
    buffer[l] = '\n';
    buffer[l+1] = '\0';
  }

  fprintf(stderr, buffer);
  va_end(args);
}

/*
 * Print a debug message on stderr.
 */
void sdf_debug(char *fmt, ...) {
  va_list args;

  va_start(args, fmt);
  vfprintf(stderr, fmt, args);
  /*perror(" ");*/
  /*fprintf(stdout, "\n");*/
  va_end(args);
}

/*
 * Print a message on stdout.
 */
void sdf_print(char *fmt, ...) {
  va_list args;

  va_start(args, fmt);
  vfprintf(stdout, fmt, args);
  /*fprintf(stdout, "\n");*/
  va_end(args);
}
