/* 
 * Stardust :-) 
 * A Free Space Flight Simulator for a Free Universe!
 * Copyright (C) 2004 MiKael NAVARRO
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <stdlib.h>

#include <assert.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <sys/types.h>
#ifdef UNISTD
#include <unistd.h>
#endif

#include <SDL.h>

#include <GL/gl.h>
#include <GL/glu.h>

#include "sdlib.h"

#include "engine.h"

/*
 * Show copyleft.
 */
static int show_copyleft(void) {
  printline("Stardust is a free software\n"
	    "available under the terms of the GNU Public Licence.\n"
	    "Refer to the file COPYING (which should be included in this distribution)\n"
	    "for the specific terms of this licence.\n\n");
  return 0;
}

/* 
 * Entry point.
 */
int main(int argc, char **argv) {
  /* Engine */
  Engine *engine = NULL;

  /* Start ! */
  printline("\n"
	    "Stardust "VERSION" :-)\n"
	    "A Free Space Flight Simulator for a Free Universe!\n"
	    "\n"
	    "Copyright (C) 2004 MiKael NAVARRO\n"
	    "Stardust is distributed in the hope that it will be fun,\n"
	    "but WITHOUT ANY WARRANTY.\n\n");

  /* Create the engine */
  engine = engine_new();

  show_copyleft();

#ifdef UNISTD
  {
    uid_t uid = getuid();
    uid_t euid = geteuid();
    if(uid == 0 || euid == 0) { /* get real user, effective user */
      sd_error("Stardust doesn't allow to start itself as root,\n"
	       "for security/safety reason!");
    }
  }
#endif

  sd_debug("Compiled on %s %s\n\n", __DATE__, __TIME__);

  /* Init the Engine (conf) */
  engine_init(engine, argc, argv);

  /* Init SDL/OpenGL context */
  engine_init_graphics(engine);

  /* Init World */
  engine_load(engine);

  printline("\n...done in %d ms\n", SDL_GetTicks());
  
  /* Call the Game Loop */
  engine_gameloop(engine);

  /* Free memory */
  engine_destroy(engine);

  return(0); /* ANSI C requires main to return int */
}
