/* 
 * Stardust :-) 
 * A Free Space Flight Simulator for a Free Universe!
 * Copyright (C) 2003 MiKael NAVARRO
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*
 * Init/draw Stars field.
 */

#ifndef _STARS_H
#define _STARS_H

#include <GL/gl.h>

#include "vec3d.h"

#include "texture.h"

#define NUMSTARS 1200
#define NBSTARS (NUMSTARS/3) /* trick */

/*
 * Starsfield.
 * Can be implemented as a set of GL_POINTS,
 * and/or by a texture (nebula).
 */
typedef struct _Stars {
  GLuint id;
  vec3_t xyz[NUMSTARS]; /* x,y,z of each star */
  Texture *nebula; /* texture file */
} Stars;

/*
 * Constructor.
 */
Stars *stars_new(void);

/*
 * Destructor.
 */
int stars_destroy(Stars *stars);

/*
 * Initialize (display list).
 * If(nebula == GL_POINTS) compile a set of points,
 * Else load the nebula texture.
 */
GLuint stars_init(Stars *stars, const char *nebula_file);

/*
 * Draw starsfield (from display list).
 */
int stars_draw(Stars *stars);


#endif /* _STARS_H */
