/* Copyright (c) Mark J. Kilgard, 1997. */

/* 
 * This program is freely distributable without licensing fees  and is
 * provided without guarantee or warrantee expressed or  implied. This
 * program is -not- in the public domain. 
 */

#ifndef _TEXFONT_H
#define _TEXFONT_H

#include <GL/gl.h>

#define TXF_FORMAT_BYTE	  0
#define TXF_FORMAT_BITMAP 1

typedef struct {
  unsigned short c; /* potentially support 16-bit glyphs */
  unsigned char width;
  unsigned char height;
  signed char xoffset;
  signed char yoffset;
  signed char advance;
  char dummy; /* space holder for alignment reasons */
  short x;
  short y;
} TexGlyphInfo;

typedef struct {
  GLfloat t0[2];
  GLshort v0[2];
  GLfloat t1[2];
  GLshort v1[2];
  GLfloat t2[2];
  GLshort v2[2];
  GLfloat t3[2];
  GLshort v3[2];
  GLfloat advance;
} TexGlyphVertexInfo;

typedef struct {
  GLuint texobj;
  int tex_width;
  int tex_height;
  int max_ascent;
  int max_descent;
  int num_glyphs;
  int min_glyph;
  int range;
  unsigned char *teximage;
  TexGlyphInfo *tgi;
  TexGlyphVertexInfo *tgvi;
  TexGlyphVertexInfo **lut;
} TexFont;

extern char *txf_error_string(void);

extern TexFont *txf_load_font(const char *filename);

extern void txf_unload_font(TexFont *txf);

extern GLuint txf_establish_texture(TexFont *txf, GLuint texobj, 
                                    GLboolean setup_mipmaps);

extern void txf_bind_font_texture(TexFont *txf);

extern void txf_get_string_metrics(TexFont *txf, char *string, int len,
                                   int *width, int *max_ascent, int *max_descent);

extern void txf_render_glyph(TexFont *txf, int c);

extern void txf_render_string(TexFont *txf, const char *string, int len);

extern void txf_render_fancy_string(TexFont *txf, char *string, int len);

#endif /* _TEXFONT_H */
