/* 
 * Stardust :-) 
 * A Free Space Flight Simulator for a Free Universe!
 * Copyright (C) 2003 MiKael NAVARRO
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <stdlib.h>
#include <string.h>

#include <assert.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <libxml/xpath.h>

#include "sdlib.h"

#include "xml.h"

/*
 * Constructor.
 */
Xml *xml_new(void) {
  /* Allocation de la structure */
  Xml *xml = (Xml *)malloc(sizeof(Xml));
  if(!xml) {
    sd_error("Can't allocate memory (Xml)!");
  }

  /* Xml init */
  xml->doc = NULL;

  return xml;
}

/*
 * Destructor.
 */
int xml_destroy(Xml *xml) {
  /* Assertion */
  assert(xml);
  assert(xml->doc);

  /* Free memory */
  xmlFreeDoc(xml->doc);
  free(xml);

  return 0;
}

/*
 * Init xml document from xml_file.
 */
int xml_init(Xml *xml, const char *xml_file) {
  /* Assertion */
  assert(xml);

  /* Init (thread) */
  xmlInitParser();

  /* Parse xml file */
  xml->doc = xmlParseFile(xml_file);
  if(!xml->doc) {
    char xml_file2[FILENAME_LGTH];

    printline("Trying in directory: "DATA_DIR"\n");
    strcpy(xml_file2, DATA_DIR);
    strcat(xml_file2, xml_file);

    xml->doc = xmlParseFile(xml_file2);
    if(!xml->doc) {
	sd_error("Could not parse the document %s!", xml_file);
    }
  }
  ifdebug( xmlDocDump(stderr, xml->doc); );

  return 0;
}

/*
 * Search path in xml document.
 * Return the first instance found or NULL if not found.
 */
char *xml_search_path(Xml *xml, const char *path) {
  char *val = NULL;
  xmlXPathContextPtr xml_context = NULL;
  xmlXPathObjectPtr xml_obj;

  /* Assertion */
  assert(xml);
  assert(xml->doc);

  /* Init context */
  xmlXPathInit();
  xml_context = xmlXPathNewContext(xml->doc);
  
  /* Find key (path) */
  xml_obj = xmlXPathEval(path, xml_context);
  if( (xml_obj->type == XPATH_NODESET) &&
      (xml_obj->nodesetval) ) {

    if(xml_obj->nodesetval->nodeNr) {
      xmlNodePtr node = xml_obj->nodesetval->nodeTab[0];
      if( (node->type == XML_TEXT_NODE) ||
	  (node->type == XML_CDATA_SECTION_NODE) ) {
	val = strdup(node->content);
	}
	else {
	sd_warning("Nor text or cdata node found (%d)!", node->type);
      }
    }
    else {
      sd_warning("No node found!");
    }
  }
  else if( xml_obj->type == XPATH_STRING ) {
    val = strdup(xml_obj->stringval);
  }
  else {
    sd_warning("XPath object type %d not managed yet!", xml_obj->type);
  } 
  /*dprintf("%s = %s\n", path, val);*/

  /* Release memory */
  xmlXPathFreeObject(xml_obj);
  xmlXPathFreeContext(xml_context);

  return val;
}

/*
 * Search path in xml document.
 * Return the token number n, otherwise return NULL.
 */
char *xml_search_xpath(Xml *xml, const char *path, int n) {
  char *val = NULL;
  unsigned int nr = 0;
  xmlXPathContextPtr xml_context = NULL;
  xmlXPathObjectPtr xml_obj;

  /* Assertion */
  assert(xml);
  assert(xml->doc);

  /* Init context */
  xmlXPathInit();
  xml_context = xmlXPathNewContext(xml->doc);
  
  /* Find key (path) */
  xml_obj = xmlXPathEval(path, xml_context);
  if( (xml_obj->type == XPATH_NODESET) &&
      (xml_obj->nodesetval) ) {

    if(xml_obj->nodesetval->nodeNr) {
      nr = xml_obj->nodesetval->nodeNr;
      
      if(n < nr) {
	xmlNodePtr node = xml_obj->nodesetval->nodeTab[n];
	if( (node->type == XML_TEXT_NODE) ||
	    (node->type == XML_CDATA_SECTION_NODE) ) {
	  val = strdup(node->content);
	}
	else {
	  sd_warning("Nor text or cdata node [%d] found (%d)!", n, node->type);
	}
      }
    }
    else {
      sd_warning("No node found!");
    }
  }
  else if( xml_obj->type == XPATH_STRING ) {
    val = strdup(xml_obj->stringval);
  }
  else {
    sd_warning("XPath object type %d not managed yet!", xml_obj->type);
  } 
  /*dprintf("%s = %s\n", path, val);*/

  /* Release memory */
  xmlXPathFreeObject(xml_obj);
  xmlXPathFreeContext(xml_context);

  return val;
}
